Learn R Programming

RBE3 (version 1.1)

gumbel2: The Gumbel2 distribution

Description

Density, distribution function and quantile function for the Gumbel2 distribution.

Usage

dgumbel2(x, log=FALSE)
pgumbel2(q)
qgumbel2(p)

Value

dgumbel2 gives the density, pgumbel2 gives the distribution function and qgumbel2 gives the quantile function.

The length of the result is determined by the maximum of the lengths of the numerical arguments.

Arguments

x, q

Vector of quantiles.

p

Vector of probabilities.

log

logical; if TRUE, probabilities p are given as log(p).

Author

Diego Gallardo and Marcelo Bourguignon.

Details

The cumulative distribution function for the Gumbel2 distribution is given by \(F(x)=1-exp(-exp(x)).\)

Examples

Run this code
dgumbel2(c(4,10))
pgumbel2(c(4,10))
qgumbel2(c(0.1, 0.5))

Run the code above in your browser using DataLab