powered by
Density, distribution function and quantile function for the Gumbel2 distribution.
dgumbel2(x, log=FALSE) pgumbel2(q) qgumbel2(p)
dgumbel2 gives the density, pgumbel2 gives the distribution function and qgumbel2 gives the quantile function.
The length of the result is determined by the maximum of the lengths of the numerical arguments.
Vector of quantiles.
Vector of probabilities.
logical; if TRUE, probabilities p are given as log(p).
Diego Gallardo and Marcelo Bourguignon.
The cumulative distribution function for the Gumbel2 distribution is given by \(F(x)=1-exp(-exp(x)).\)
dgumbel2(c(4,10)) pgumbel2(c(4,10)) qgumbel2(c(0.1, 0.5))
Run the code above in your browser using DataLab